==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/statistiques/lang/statistiques_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/statistiques?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'archiver' => 'Archivovať',
	'archiver_concatener_explications' => 'Táto operácia zreťazí štatistiky návštev článkov:',
	'archiver_nombre_lignes' => 'Počet riadkov',
	'archiver_operations_irreversibles' => 'Tieto operácie sa nedajú vrátiť späť!',

	// B
	'bouton_effacer_referers' => 'Odstrániť len prichádzajúce odkazy',
	'bouton_effacer_statistiques' => 'Vymazať všetky štatistiky',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Počet návštev<br />@visites@ návštev',
	'icone_repartition_actuelle' => 'Zobraziť aktuálne rozdelenie',
	'icone_repartition_visites' => 'Rozdelenie návštev',
	'icone_statistiques_visites' => 'Štatistiky',
	'info_affichier_visites_articles_plus_visites' => 'Prehľad počtu návštev pre <b>najviac navštevované články od začiatku:</b>',
	'info_comment_lire_tableau' => 'Ako čítať tento graf',
	'info_forum_statistiques' => 'Štatistiky návštev',
	'info_graphiques' => 'Grafika',
	'info_popularite_2' => 'popularita stránky:',
	'info_popularite_3' => 'popularita: @popularite@, návštev: @visites@',
	'info_popularite_5' => 'popularita:',
	'info_previsions' => 'predpovede:',
	'info_question_vignettes_referer' => 'Keď sa pozriete do štatistiky, uvidíte ukážku každej stránky, z ktorej prišiel nejaký návštevník. ',
	'info_question_vignettes_referer_oui' => 'Zobraziť obrázky odkazujúcich stránok',
	'info_tableaux' => 'Tabuľky',
	'info_visites' => 'Návštev:',
	'info_visites_plus_populaires' => 'Prehľad počtu návštev   <b>najpopulárnejších</b> a <b>najnovších článkov:</b>',
	'info_zoom' => 'lupa',
	'item_gerer_statistiques' => 'Riadiť štatistiky návštev',

	// O
	'onglet_origine_visites' => 'Pôvod návštev',
	'onglet_repartition_debut' => 'od začiatku',
	'onglet_repartition_lang' => 'Rozdelenie podľa jazykov',

	// R
	'resume' => 'Súhrn',

	// T
	'texte_admin_effacer_stats' => 'Tento príkaz vymaže všetky štatistiky o návštevách na stránke, vrátane popularity článkov.',
	'texte_admin_effacer_toutes_stats' => 'Prvé tlačidlo vymaže všetky štatistiky: návštevy, údaje o popularite článkov a prichádzajúcich odkazoch.',
	'texte_comment_lire_tableau' => 'Hodnotenie článku podľa popularity je uvedené na okraji; popularita článku (predpoklad počtu návštev, ktoré dosiahne, ak bude pokračovať ich súčasné tempo) a počet návštev dosiahnutých od začiatku sa zobrazia v bubline, ktorá sa objaví, ak nad názvom článku prejdete myšou.',
	'texte_signification' => 'Tmavé čiary znázorňujú kumulatívne vstupy (celkom za podrubriky), svetlé čiary znázorňujú počet návštev každej rubriky.',
	'titre_evolution_visite' => 'Vývoj počtu návštev',
	'titre_liens_entrants' => 'Prichádzajúce odkazy',
	'titre_page_statistiques' => 'Štatistiky podľa rubrík',
	'titre_page_statistiques_visites' => 'Štatistiky návštev',

	// V
	'visites_journalieres' => 'Počet návštev za deň',
	'visites_mensuelles' => 'Počet návštev za mesiac'
);

?>

==> spip_3.2.7.orig.tar.xz: spip/plugins-dist/statistiques/lang/statistiques_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'archiver' => 'Archivovať',
	'archiver_concatener_explications' => 'Táto operácia zreťazí štatistiky návštev článkov:',
	'archiver_concatener_ignorer' => 'Návštevy za minimálne @nb@ rok(y)/rokov to neovplyvní.',
	'archiver_concatener_par_an' => 'Ďalšie návštevy za @nb@ rok(y)/rokov za každý článok v prvý deň roka sa sčítajú.',
	'archiver_concatener_par_mois' => 'Ďalšie návštevy za @nb@ rok(y)/rokov za každý článok v prvý deň mesiaca sa sčítajú.',
	'archiver_conseil_sauvegarde' => 'V prvom kroku sa odporúča zálohovať databázu.',
	'archiver_description' => 'Táto stránka vám ponúka nástroje na vynulovanie a archiváciu štatistík stránky.',
	'archiver_et_nettoyer' => 'Archivovať a vynulovať',
	'archiver_nettoyer' => 'Vynulovať',
	'archiver_nettoyer_explications' => 'Vymaže riadky o "refereroch" a "návštevách", ku ktorým (už viac)  v databáze neexistujú položky.',
	'archiver_nettoyer_referers_articles' => 'Vynulovať referers_articles',
	'archiver_nettoyer_visites_articles' => 'Vynulovať visites_articles',
	'archiver_nombre_lignes' => 'Počet riadkov',
	'archiver_operation_longue' => 'Táto operácia môže pri prvom spustení zabrať veľa času.',
	'archiver_operations_irreversibles' => 'Tieto operácie sa nedajú vrátiť späť!',

	// B
	'bouton_effacer_referers' => 'Odstrániť len prichádzajúce odkazy',
	'bouton_effacer_statistiques' => 'Vymazať všetky štatistiky',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Počet návštev<br />@visites@ návštev',
	'icone_repartition_actuelle' => 'Zobraziť aktuálne rozdelenie',
	'icone_repartition_visites' => 'Rozdelenie návštev',
	'icone_statistiques_visites' => 'Štatistiky',
	'info_affichier_visites_articles_plus_visites' => 'Prehľad počtu návštev pre <b>najviac navštevované články od začiatku:</b>',
	'info_comment_lire_tableau' => 'Ako čítať tento graf',
	'info_forum_statistiques' => 'Štatistiky návštev',
	'info_graphiques' => 'Grafika',
	'info_popularite_2' => 'popularita stránky:',
	'info_popularite_3' => 'popularita: @popularite@, návštev: @visites@',
	'info_popularite_5' => 'popularita:',
	'info_previsions' => 'predpovede:',
	'info_question_vignettes_referer' => 'Keď sa pozriete do štatistiky, uvidíte ukážku každej stránky, z ktorej prišiel nejaký návštevník. ',
	'info_question_vignettes_referer_oui' => 'Zobraziť obrázky odkazujúcich stránok',
	'info_referer_oui' => 'Aktivovať prichádzajúce odkazy',
	'info_tableaux' => 'Tabuľky',
	'info_visites' => 'Návštev:',
	'info_visites_plus_populaires' => 'Prehľad počtu návštev   <b>najpopulárnejších</b> a <b>najnovších článkov:</b>',
	'info_zoom' => 'lupa',
	'item_gerer_statistiques' => 'Riadiť štatistiky návštev',

	// O
	'onglet_origine_visites' => 'Pôvod návštev',
	'onglet_repartition_debut' => 'od začiatku',
	'onglet_repartition_lang' => 'Rozdelenie podľa jazykov',

	// R
	'resume' => 'Súhrn',

	// T
	'texte_admin_effacer_stats' => 'Tento príkaz vymaže všetky štatistiky o návštevách na stránke, vrátane popularity článkov.',
	'texte_admin_effacer_toutes_stats' => 'Prvé tlačidlo vymaže všetky štatistiky: návštevy, údaje o popularite článkov a prichádzajúcich odkazoch.',
	'texte_comment_lire_tableau' => 'Hodnotenie článku podľa popularity je uvedené na okraji; popularita článku (predpoklad počtu návštev, ktoré dosiahne, ak bude pokračovať ich súčasné tempo) a počet návštev dosiahnutých od začiatku sa zobrazia v bubline, ktorá sa objaví, ak nad názvom článku prejdete myšou.',
	'texte_signification' => 'Tmavé čiary znázorňujú kumulatívne vstupy (celkom za podrubriky), svetlé čiary znázorňujú počet návštev každej rubriky.',
	'titre_evolution_visite' => 'Vývoj počtu návštev',
	'titre_liens_entrants' => 'Prichádzajúce odkazy',
	'titre_page_statistiques' => 'Štatistiky podľa rubrík',
	'titre_page_statistiques_visites' => 'Štatistiky návštev',

	// V
	'visites_journalieres' => 'Počet návštev za deň',
	'visites_mensuelles' => 'Počet návštev za mesiac'
);
